@@ -1,6 +1,6 @@
 #!perl -w
 #
-# $Id: exe_wrap.pl,v 1.31 2004/03/06 12:04:48 epaepa Exp $
+# $Id: exe_wrap.pl,v 1.41 2004/04/13 22:20:55 epaepa Exp $
 # This is a quick XMLTV shell routing to use with the windows exe
 #
 # A single EXE is needed to allow sharing of modules and dlls of all the
@@ -60,23 +60,20 @@ print STDERR "Timezone is $ENV{TZ}\n";
 $cmd = shift || "";
 
 # --version (and abbreviations thereof)
-my $VERSION = '0.5.30';
+my $VERSION = '0.5.32';
 if (index('--version', $cmd) == 0 and length $cmd >= 3) {
     print "xmltv $VERSION\n";
     exit;
 }
 
 #
-# check for tv_grab_nz
+# some grabbers aren't included
 #
-if ($cmd eq 'tv_grab_nz') {
+if ($cmd =~ /^tv_grab_(?:nz|jp|se)$/) {
     die <<END
-Sorry, tv_grab_nz is not available in this Windows binary release,
-although if you have Python installed you will be able to get it from
-the xmltv source distribution.
+Sorry, $cmd is not available in this Windows binary release, although
+it is included in xmltv source releases.
 
-It is hoped that future Windows binaries for xmltv will include a way
-to run tv_grab_nz.
 END
   ;
 };
@@ -114,7 +111,7 @@ foreach my $exe (split(/ /,$files))
     next unless length($exe)>3; #ignore trash
     $_=$exe;
     s!^.+/!!g;
-    push @cmds,$_;  # build command list (just in case)
+    $cmds{$_}=1;  # build command list (just in case)
 
     next unless $cmd eq $_;
 
@@ -122,8 +119,8 @@ foreach my $exe (split(/ /,$files))
 # execute our command
 #
     $0 = $_;        # set $0 to our script
-    $r = require $exe;
-    exit $r;
+    do $exe;
+    exit 0;
 }
 
 #
@@ -131,10 +128,23 @@ foreach my $exe (split(/ /,$files))
 #
 if ($cmd eq "" )
    {
-	die "you must specify the program to run, for example: $0 tv_grab_fi --configure\n";
+	print STDERR "you must specify the program to run\n    for example: $0 tv_grab_fi --configure\n";
     }
 else
    {
-	die "$cmd is not a valid command. Valid commands are:\n".join(" ",@cmds)."\n";
+    print STDERR "$cmd is not a valid command.\n";
    }
 
+print STDERR "Valid commands are:\n";
+@cmds=sort keys %cmds;
+$rows = int($#cmds / 3)+1;
+
+map {$_='' unless defined $_} @cmds[0..($rows*3+2)];    
+unshift @cmds,undef;
+
+foreach (1..$rows)
+{
+   printf STDERR "    %-20s %-20s %-20s\n",@cmds[$_,$rows+$_,2*$rows+$_];
+}
+exit 1;
+
